@@ -25,6 +25,13 @@ def main():
         help="JPEG output quality (0-100)",
         default=CompressPptx.DEFAULT_QUALITY,
     )
+    parser.add_argument(
+        "-t",
+        "--transparency",
+        type=str,
+        help="Replace transparency with color",
+        default=CompressPptx.DEFAULT_TRANSPARENCY,
+    )
     parser.add_argument(
         "-v", "--verbose", action="store_true", help="Show additional info"
     )
